operators

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: Apache-2.0 Imports: 28 Imported by: 0

Documentation

Overview

Package operators implements SecLang rule operators for matching and validation.

Operators are functions that evaluate input data and return true or false. They are used in `SecRule` directives with the syntax: `@operatorName argument`

Example:

``` SecRule ARGS "@contains evil" "id:100,deny" ```

Operators can be negated using the ! prefix:

``` SecRule REQUEST_LINE "!@beginsWith GET" "id:101,deny" ```

For the complete list of available operators, see: https://coraza.io/docs/seclang/operators/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

Get returns an operator by name

func NewValidateSchema added in v3.4.0

func NewValidateSchema(options plugintypes.OperatorOptions) (plugintypes.Operator, error)

NewValidateSchema creates a new validateSchema operator

func Register

func Register(name string, op plugintypes.OperatorFactory)

Register registers a new operator If the operator already exists it will be overwritten

Types

This section is empty.

Jump to