Documentation
¶
Overview ¶
Package operators implements SecLang rule operators for matching and validation.
Operators are functions that evaluate input data and return true or false. They are used in `SecRule` directives with the syntax: `@operatorName argument`
Example:
``` SecRule ARGS "@contains evil" "id:100,deny" ```
Operators can be negated using the ! prefix:
``` SecRule REQUEST_LINE "!@beginsWith GET" "id:101,deny" ```
For the complete list of available operators, see: https://coraza.io/docs/seclang/operators/
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Get ¶
func Get(name string, options plugintypes.OperatorOptions) (plugintypes.Operator, error)
Get returns an operator by name
func NewValidateSchema ¶ added in v3.4.0
func NewValidateSchema(options plugintypes.OperatorOptions) (plugintypes.Operator, error)
NewValidateSchema creates a new validateSchema operator
func Register ¶
func Register(name string, op plugintypes.OperatorFactory)
Register registers a new operator If the operator already exists it will be overwritten
Types ¶
This section is empty.
Source Files
¶
- begins_with.go
- contains.go
- detect_sqli.go
- detect_xss.go
- ends_with.go
- eq.go
- from_file.go
- ge.go
- geo_lookup.go
- gt.go
- inspect_file.go
- ip_match.go
- ip_match_from_dataset.go
- ip_match_from_file.go
- le.go
- lt.go
- multilineregex_default.go
- no_match.go
- operators.go
- pm.go
- pm_from_dataset.go
- pm_from_file.go
- rbl.go
- restpath.go
- rx.go
- rxprefilter.go
- streq.go
- strmatch.go
- unconditional_match.go
- validate_byte_range.go
- validate_nid.go
- validate_schema.go
- validate_url_encoding.go
- validate_utf8_encoding.go
- within.go